@@ -1,4 +1,6 @@
+# pylint: disable=consider-using-from-import
+import itchiodl.utils as utils
 from .login import LoginWeb, LoginAPI
 from .bundle import Bundle
 from .library import Library
-from .game import Game
\ No newline at end of file
+from .game import Game
